@@ -4,10 +4,13 @@ OC.L10N.register(
     "Notes" : "الملاحظات",
     "Error" : "خطأ",
     "New note" : "ملاحظة جديدة ",
-    "Settings" : "الإعدادات",
+    "Display mode for notes" : "وضع العرض للملاحظات",
+    "Open in edit mode" : "فتح في وضع التحرير",
+    "Open in preview mode" : "فتح في وضع المعاينة",
     "No notes yet" : "لا ملاحظات حاليا",
     "All notes" : "جميع الملاحظات",
     "Categories" : "الفئات",
+    "Loading …" : "جاري التحميل …",
     "Today" : "اليوم",
     "Yesterday" : "البارحة",
     "This week" : "هذا الأسبوع",
