@@ -1,12 +1,13 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
+    "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nota nueva",
-    "Notes" : "Notas",
-    "Settings" : "Configuraciones ",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "Open in edit mode" : "Abrir en modo edición",
+    "Open in preview mode" : "Abrir en modo previsualización",
+    "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "Today" : "Hoy",
@@ -18,13 +19,13 @@ OC.L10N.register(
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Details" : "Detalles",
-    "Preview" : "Previsualizar",
     "Edit" : "Editar",
+    "Preview" : "Previsualizar",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
