@@ -5,8 +5,11 @@ OC.L10N.register(
     "Error" : "오류",
     "New note" : "새 메모",
     "There are unsaved notes. Leaving the page will discard all changes!" : "저장하지 않은 메모가 있습니다. 이 페이지를 벗어나면 변경 사항이 손실됩니다!",
-    "Settings" : "설정",
+    "Display mode for notes" : "노트 표시 모드",
+    "Open in edit mode" : "편집 모드로 열기",
+    "Open in preview mode" : "미리 보기 모드로 열기",
     "No notes yet" : "아직 메모 없음",
+    "All notes" : "모든 메모",
     "Categories" : "분류",
     "Loading …" : "불러오는 중 …",
     "Today" : "오늘",
@@ -19,6 +22,7 @@ OC.L10N.register(
     "Delete note" : "메모 삭제",
     "Remove from favorites" : "즐겨찾기에서 제거",
     "Add to favorites" : "즐겨찾기에 추가",
+    "Use current version" : "최근 버전을 사용하십시오.",
     "Details" : "세부사항",
     "Edit" : "편집",
     "Preview" : "미리 보기",
