@@ -4,10 +4,10 @@ OC.L10N.register(
     "Notes" : "Тэмдэглэл",
     "Error" : "Алдаа",
     "New note" : "Шинэ тэмдэглэл",
-    "Settings" : "Тохиргоо",
     "No notes yet" : "шинэ тэмдэглэл алга",
     "All notes" : "Бүх тэмдэг",
     "Categories" : "төрөл",
+    "Loading …" : "Уншиж байна...",
     "Today" : "өнөөдөр",
     "Yesterday" : "өчигдөр",
     "This week" : "7 хоног",
