@@ -4,7 +4,9 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Error" : "Greška",
     "New note" : "Nova beleška",
-    "Settings" : "Postavke",
+    "Display mode for notes" : "Režim prikaza beleški",
+    "Open in edit mode" : "Otvori u režimu uređivanja",
+    "Open in preview mode" : "Otvori u režimu pregleda",
     "No notes yet" : "Još nema beleški",
     "All notes" : "Sve beleške",
     "Today" : "Today",
