@@ -13,14 +13,13 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
-    "Settings" : "Inställningar",
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
-    "path to notes" : "sökväg till anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
     "Display mode for notes" : "Visningsläge för anteckningar",
     "Open in edit mode" : "Öppna i redigeringsläge",
     "Open in preview mode" : "Öppna i granskningsläge",
     "No notes yet" : "Inga anteckningar än",
+    "Insert image" : "Infoga bild",
     "All notes" : "Alla anteckningar",
     "Categories" : "Kategorier",
     "Loading …" : "Läser in ...",
