@@ -5,7 +5,9 @@ declare(strict_types=1);
 namespace OCA\Notes\Controller;
 
 use OCA\Notes\Service\NotesService;
+use OCA\Notes\Service\MetaNote;
 use OCA\Notes\Service\MetaService;
+use OCA\Notes\Service\SettingsService;
 
 use OCP\AppFramework\ApiController;
 use OCP\AppFramework\Http;
@@ -13,24 +15,23 @@ use OCP\AppFramework\Http\JSONResponse;
 use OCP\IRequest;
 
 class NotesApiController extends ApiController {
-
-	/** @var NotesService */
-	private $service;
-	/** @var MetaService */
-	private $metaService;
-	/** @var Helper */
-	private $helper;
+	private NotesService $service;
+	private MetaService $metaService;
+	private SettingsService $settingsService;
+	private Helper $helper;
 
 	public function __construct(
 		string $AppName,
 		IRequest $request,
 		NotesService $service,
 		MetaService $metaService,
+		SettingsService $settingsService,
 		Helper $helper
 	) {
 		parent::__construct($AppName, $request);
 		$this->service = $service;
 		$this->metaService = $metaService;
+		$this->settingsService = $settingsService;
 		$this->helper = $helper;
 	}
 
@@ -40,29 +41,41 @@ class NotesApiController extends ApiController {
 	 * @CORS
 	 * @NoCSRFRequired
 	 */
-	public function index(?string $category = null, string $exclude = '', int $pruneBefore = 0) : JSONResponse {
-		return $this->helper->handleErrorResponse(function () use ($category, $exclude, $pruneBefore) {
+	public function index(
+		?string $category = null,
+		string $exclude = '',
+		int $pruneBefore = 0,
+		int $chunkSize = 0,
+		string $chunkCursor = null
+	) : JSONResponse {
+		return $this->helper->handleErrorResponse(function () use (
+			$category,
+			$exclude,
+			$pruneBefore,
+			$chunkSize,
+			$chunkCursor
+		) {
+			// initialize settings
+			$userId = $this->helper->getUID();
+			$this->settingsService->getAll($userId, true);
+			// load notes and categories
 			$exclude = explode(',', $exclude);
-			$now = new \DateTime(); // this must be before loading notes if there are concurrent changes possible
-			$notes = $this->service->getAll($this->helper->getUID())['notes'];
-			$metas = $this->metaService->updateAll($this->helper->getUID(), $notes);
-			if ($category !== null) {
-				$notes = array_values(array_filter($notes, function ($note) use ($category) {
-					return $note->getCategory() === $category;
-				}));
+			$data = $this->helper->getNotesAndCategories($pruneBefore, $exclude, $category, $chunkSize, $chunkCursor);
+			$notesData = $data['notesData'];
+			if (!$data['chunkCursor']) {
+				// if last chunk, then send all notes (pruned)
+				$notesData += array_map(function (MetaNote $m) {
+					return [ 'id' => $m->note->getId() ];
+				}, $data['notesAll']);
 			}
-			$notesData = array_map(function ($note) use ($metas, $pruneBefore, $exclude) {
-				$lastUpdate = $metas[$note->getId()]->getLastUpdate();
-				if ($pruneBefore && $lastUpdate < $pruneBefore) {
-					return [ 'id' => $note->getId() ];
-				} else {
-					return $note->getData($exclude);
-				}
-			}, $notes);
-			$etag = md5(json_encode($notesData));
-			return (new JSONResponse($notesData))
-				->setLastModified($now)
-				->setETag($etag);
+			$response = new JSONResponse(array_values($notesData));
+			$response->setLastModified($data['lastUpdate']);
+			$response->setETag(md5(json_encode($notesData)));
+			if ($data['chunkCursor']) {
+				$response->addHeader('X-Notes-Chunk-Cursor', $data['chunkCursor']->toString());
+				$response->addHeader('X-Notes-Chunk-Pending', $data['numPendingNotes']);
+			}
+			return $response;
 		});
 	}
 
@@ -76,7 +89,10 @@ class NotesApiController extends ApiController {
 		return $this->helper->handleErrorResponse(function () use ($id, $exclude) {
 			$exclude = explode(',', $exclude);
 			$note = $this->service->get($this->helper->getUID(), $id);
-			return $note->getData($exclude);
+			$noteData = $this->helper->getNoteData($note, $exclude);
+			return (new JSONResponse($noteData))
+				->setETag($noteData['etag'])
+			;
 		});
 	}
 
@@ -108,7 +124,7 @@ class NotesApiController extends ApiController {
 				$this->service->delete($this->helper->getUID(), $note->getId());
 				throw $e;
 			}
-			return $note->getData();
+			return $this->helper->getNoteData($note);
 		});
 	}
 
@@ -151,23 +167,22 @@ class NotesApiController extends ApiController {
 			$category,
 			$favorite
 		) {
-			$note = $this->service->get($this->helper->getUID(), $id);
-			if ($content !== null) {
+			$note = $this->helper->getNoteWithETagCheck($id, $this->request);
+			if ($content !== null && $content !== $note->getContent()) {
 				$note->setContent($content);
 			}
-			if ($modified !== null) {
+			if ($modified !== null && $modified !== $note->getModified()) {
 				$note->setModified($modified);
 			}
-			if ($title !== null) {
+			if ($title !== null && $title !== $note->getTitle()) {
 				$note->setTitleCategory($title, $category);
-			} elseif ($category !== null) {
+			} elseif ($category !== null && $category !== $note->getCategory()) {
 				$note->setCategory($category);
 			}
-			if ($favorite !== null) {
+			if ($favorite !== null && $favorite !== $note->getFavorite()) {
 				$note->setFavorite($favorite);
 			}
-			$this->metaService->update($this->helper->getUID(), $note);
-			return $note->getData();
+			return $this->helper->getNoteData($note);
 		});
 	}
 
@@ -207,6 +222,28 @@ class NotesApiController extends ApiController {
 		});
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 */
+	public function setSettings() : JSONResponse {
+		return $this->helper->handleErrorResponse(function () {
+			$this->settingsService->setPublic($this->helper->getUID(), $this->request->getParams());
+			return $this->getSettings();
+		});
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 */
+	public function getSettings() : JSONResponse {
+		return $this->helper->handleErrorResponse(function () {
+			return $this->settingsService->getPublic($this->helper->getUID());
+		});
+	}
 	/**
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
