@@ -7,11 +7,12 @@ namespace OCA\Notes\Service;
 use OCP\Files\File;
 use OCP\Files\FileInfo;
 use OCP\Files\Folder;
+use OCP\Files\NotPermittedException;
 
 class NotesService {
-	private $metaService;
-	private $settings;
-	private $noteUtil;
+	private MetaService $metaService;
+	private SettingsService $settings;
+	private NoteUtil $noteUtil;
 
 	public function __construct(
 		MetaService $metaService,
@@ -23,19 +24,25 @@ class NotesService {
 		$this->noteUtil = $noteUtil;
 	}
 
-	public function getAll(string $userId) : array {
-		$notesFolder = $this->getNotesFolder($userId);
-		$data = $this->gatherNoteFiles($notesFolder);
-		$fileIds = array_keys($data['files']);
-		// pre-load tags for all notes (performance improvement)
-		$this->noteUtil->getTagService()->loadTags($fileIds);
-		$notes = array_map(function (File $file) use ($notesFolder) : Note {
-			return new Note($file, $notesFolder, $this->noteUtil);
-		}, $data['files']);
+	public function getAll(string $userId, bool $autoCreateNotesFolder = false) : array {
+		$customExtension = $this->getCustomExtension($userId);
+		try {
+			$notesFolder = $this->getNotesFolder($userId, $autoCreateNotesFolder);
+			$data = self::gatherNoteFiles($customExtension, $notesFolder);
+			$fileIds = array_keys($data['files']);
+			// pre-load tags for all notes (performance improvement)
+			$this->noteUtil->getTagService()->loadTags($fileIds);
+			$notes = array_map(function (File $file) use ($notesFolder) : Note {
+				return new Note($file, $notesFolder, $this->noteUtil);
+			}, $data['files']);
+		} catch (NotesFolderException $e) {
+			$notes = [];
+			$data = [ 'categories' => [] ];
+		}
 		return [ 'notes' => $notes, 'categories' => $data['categories'] ];
 	}
 
-	public function getTopNotes(string $userId, int $count) : array {
+	public function getTopNotes(string $userId) : array {
 		$notes = $this->getAll($userId)['notes'];
 		usort($notes, function (Note $a, Note $b) {
 			$favA = $a->getFavorite();
@@ -46,12 +53,13 @@ class NotesService {
 				return $favA > $favB ? -1 : 1;
 			}
 		});
-		return array_slice($notes, 0, $count);
+		return $notes;
 	}
 
 	public function get(string $userId, int $id) : Note {
+		$customExtension = $this->getCustomExtension($userId);
 		$notesFolder = $this->getNotesFolder($userId);
-		$note = new Note($this->getFileById($notesFolder, $id), $notesFolder, $this->noteUtil);
+		$note = new Note(self::getFileById($customExtension, $notesFolder, $id), $notesFolder, $this->noteUtil);
 		$this->metaService->update($userId, $note);
 		return $note;
 	}
@@ -101,8 +109,10 @@ class NotesService {
 
 		// get file name
 		$fileSuffix = $this->settings->get($userId, 'fileSuffix');
+		if ($fileSuffix === "custom") {
+			$fileSuffix = $this->settings->get($userId, 'customSuffix');
+		}
 		$filename = $this->noteUtil->generateFileName($folder, $title, $fileSuffix, -1);
-
 		// create file
 		$file = $folder->newFile($filename);
 
@@ -114,8 +124,9 @@ class NotesService {
 	 * @throws NoteDoesNotExistException if note does not exist
 	 */
 	public function delete(string $userId, int $id) {
+		$customExtension = $this->getCustomExtension($userId);
 		$notesFolder = $this->getNotesFolder($userId);
-		$file = $this->getFileById($notesFolder, $id);
+		$file = self::getFileById($customExtension, $notesFolder, $id);
 		$this->noteUtil->ensureNoteIsWritable($file);
 		$parent = $file->getParent();
 		$file->delete();
@@ -136,17 +147,21 @@ class NotesService {
 	 * @param string $userId the user id
 	 * @return Folder
 	 */
-	private function getNotesFolder(string $userId) : Folder {
+	private function getNotesFolder(string $userId, bool $create = true) : Folder {
 		$userPath = $this->noteUtil->getRoot()->getUserFolder($userId)->getPath();
 		$path = $userPath . '/' . $this->settings->get($userId, 'notesPath');
-		$folder = $this->noteUtil->getOrCreateFolder($path);
+		$folder = $this->noteUtil->getOrCreateFolder($path, $create);
 		return $folder;
 	}
 
 	/**
 	 * gather note files in given directory and all subdirectories
 	 */
-	private static function gatherNoteFiles(Folder $folder, string $categoryPrefix = '') : array {
+	private static function gatherNoteFiles(
+		string $customExtension,
+		Folder $folder,
+		string $categoryPrefix = ''
+	) : array {
 		$data = [
 			'files' => [],
 			'categories' => [],
@@ -156,10 +171,10 @@ class NotesService {
 			if ($node->getType() === FileInfo::TYPE_FOLDER && $node instanceof Folder) {
 				$subCategory = $categoryPrefix . $node->getName();
 				$data['categories'][] = $subCategory;
-				$data_sub = self::gatherNoteFiles($node, $subCategory . '/');
+				$data_sub = self::gatherNoteFiles($customExtension, $node, $subCategory . '/');
 				$data['files'] = $data['files'] + $data_sub['files'];
 				$data['categories'] = $data['categories'] + $data_sub['categories'];
-			} elseif (self::isNote($node)) {
+			} elseif (self::isNote($node, $customExtension)) {
 				$data['files'][$node->getId()] = $node;
 			}
 		}
@@ -169,21 +184,88 @@ class NotesService {
 	/**
 	 * test if file is a note
 	 */
-	private static function isNote(FileInfo $file) : bool {
+	private static function isNote(FileInfo $file, string $customExtension) : bool {
 		static $allowedExtensions = ['txt', 'org', 'markdown', 'md', 'note'];
 		$ext = strtolower(pathinfo($file->getName(), PATHINFO_EXTENSION));
-		return $file->getType() === 'file' && in_array($ext, $allowedExtensions);
+		return $file->getType() === 'file' && (in_array($ext, $allowedExtensions) || $ext === $customExtension);
+	}
+
+	/**
+	 * Retrieve the value of user defined files extension
+	 */
+	private function getCustomExtension(string $userId) {
+		$suffix = $this->settings->get($userId, 'customSuffix');
+		return ltrim($suffix, ".");
 	}
 
 	/**
 	 * @throws NoteDoesNotExistException
 	 */
-	private static function getFileById(Folder $folder, int $id) : File {
+	private static function getFileById(string $customExtension, Folder $folder, int $id) : File {
 		$file = $folder->getById($id);
 
-		if (!array_key_exists(0, $file) || !($file[0] instanceof File) || !self::isNote($file[0])) {
+		if (!array_key_exists(0, $file) || !($file[0] instanceof File) || !self::isNote($file[0], $customExtension)) {
 			throw new NoteDoesNotExistException();
 		}
 		return $file[0];
 	}
+
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 * @return \OCP\Files\File
+	 */
+	public function getAttachment(string $userId, int $noteid, string $path) : File {
+		$note = $this->get($userId, $noteid);
+		$notesFolder = $this->getNotesFolder($userId);
+		$path = str_replace('\\', '/', $path); // change windows style path
+		$p = explode('/', $note->getCategory());
+		// process relative target path
+		foreach (explode('/', $path) as $f) {
+			if ($f == '..') {
+				array_pop($p);
+			} elseif ($f !== '') {
+				array_push($p, $f);
+			}
+		}
+		$targetNode = $notesFolder->get(implode('/', $p));
+		assert($targetNode instanceof \OCP\Files\File);
+		return $targetNode;
+	}
+
+	/**
+	 * @param $userId
+	 * @param $noteid
+	 * @param $fileDataArray
+	 * @throws NotPermittedException
+	 * @throws ImageNotWritableException
+	 * https://github.com/nextcloud/deck/blob/master/lib/Service/AttachmentService.php
+	 */
+	public function createImage(string $userId, int $noteid, $fileDataArray) {
+		$note = $this->get($userId, $noteid);
+		$notesFolder = $this->getNotesFolder($userId);
+		$parent = $this->noteUtil->getCategoryFolder($notesFolder, $note->getCategory());
+
+		// try to generate long id, if not available on system fall back to a shorter one
+		try {
+			$filename = bin2hex(random_bytes(16));
+		} catch (\Exception $e) {
+			$filename = uniqid();
+		}
+		$filename = $filename . '.' . explode('.', $fileDataArray['name'])[1];
+
+		if ($fileDataArray['tmp_name'] === "") {
+			throw new ImageNotWritableException();
+		}
+
+		// read uploaded file from disk
+		$fp = fopen($fileDataArray['tmp_name'], 'r');
+		$content = fread($fp, $fileDataArray['size']);
+		fclose($fp);
+
+		$result = [];
+		$result['filename'] = $filename;
+		$this->noteUtil->getRoot()->newFile($parent->getPath() . '/' . $filename, $content);
+		return $result;
+	}
 }
